#include <stdio.h>
#include <stdlib.h>

const long MAX_TREES_COUNT = 110; //100

struct tPoint2D
{
	long y, x;
	void Read(void)
	{
		scanf("%ld %ld", &x, &y);
	}
};

template<class Type>
Type Min(const Type& a, const Type& b)
{
	return a < b ? a : b;
}

typedef int (*tpQSortCompareFunction) (const void*, const void*);

int TreesXYCompare(const tPoint2D* point1, const tPoint2D* point2)
{
	if(point1->x < point2->x) return -1;
	if(point1->x > point2->x) return 1;
	if(point1->y < point2->y) return -1;
	if(point1->y > point2->y) return 1;
	return 0;
}

int TreesYXCompare(const tPoint2D* point1, const tPoint2D* point2)
{
	if(point1->y < point2->y) return -1;
	if(point1->y > point2->y) return 1;
	if(point1->x < point2->x) return -1;
	if(point1->x > point2->x) return 1;
	return 0;
}

long cTrees;
tPoint2D	treesSortedXY[MAX_TREES_COUNT],
			treesSortedYX[MAX_TREES_COUNT];
tPoint2D fieldSize;
long maxSquareSide = 0;
tPoint2D maxSquareBottomLeft;

long FindNextXBetween(long iStartTree, long bottomBorder, long topBorder)
{
	if(iStartTree == cTrees)return -1;
	static long iTree;
	for(iTree = iStartTree + 1; iTree < cTrees; ++iTree)
		if(treesSortedXY[iTree].y > bottomBorder && treesSortedXY[iTree].y < topBorder)
			return iTree;
	return iTree;
}

long FindNextYBetween(long iStartTree, long leftBorder, long rightBorder)
{
	if(iStartTree == cTrees)return -1;
	static long iTree;
	for(iTree = iStartTree + 1; iTree < cTrees; ++iTree)
		if(treesSortedYX[iTree].x > leftBorder && treesSortedYX[iTree].x < rightBorder)
			return iTree;
	return iTree;
}

void CheckSquare(long iLeftTree, long iRightTree, long iTopTree, long iBottomTree)
{
	static long squareSide;
	static tPoint2D bottomLeft, topRight;
	if(iLeftTree == -1)bottomLeft.x = 0;
	else bottomLeft.x = treesSortedXY[iLeftTree].x;
	if(iBottomTree == -1)bottomLeft.y = 0;
	else bottomLeft.y = treesSortedYX[iBottomTree].y;
	if(iRightTree == cTrees)topRight.x = fieldSize.x;
	else topRight.x = treesSortedXY[iRightTree].x;
	if(iTopTree == cTrees)topRight.y = fieldSize.y;
	else topRight.y = treesSortedYX[iTopTree].y;
	squareSide = Min(topRight.x - bottomLeft.x, topRight.y - bottomLeft.y);
	if(squareSide > maxSquareSide)
	{
		maxSquareSide = squareSide;
		maxSquareBottomLeft = bottomLeft;
	}
}

void CheckXStripe(long iLeftTree, long iRightTree)
{
	static long iBottomTree, iTopTree;
	static long leftBorder, rightBorder;
	if(iLeftTree == -1)leftBorder = 0;
	else leftBorder = treesSortedXY[iLeftTree].x;
	if(iRightTree == cTrees)rightBorder = fieldSize.x;
	else rightBorder = treesSortedXY[iRightTree].x;
	for
	(
		iBottomTree = -1,
		iTopTree = FindNextYBetween
		(
			iBottomTree,
			leftBorder,
			rightBorder
		)
		;
		iTopTree != -1
		;
		iBottomTree = iTopTree,
		iTopTree = FindNextYBetween
		(
			iBottomTree,
			leftBorder,
			rightBorder
		)
	) CheckSquare(iLeftTree, iRightTree, iTopTree, iBottomTree);
}

void CheckYStripe(long iBottomTree, long iTopTree)
{
	static long iLeftTree, iRightTree;
	static long bottomBorder, topBorder;
	if(iBottomTree == -1)bottomBorder = 0;
	else bottomBorder = treesSortedYX[iBottomTree].y;
	if(iTopTree == cTrees)topBorder = fieldSize.y;
	else topBorder = treesSortedYX[iTopTree].y;
	for
	(
		iLeftTree = -1,
		iRightTree = FindNextXBetween
		(
			iLeftTree,
			bottomBorder,
			topBorder
		)
		;
		iRightTree != -1
		;
		iLeftTree = iRightTree,
		iRightTree = FindNextXBetween
		(
			iLeftTree,
			bottomBorder,
			topBorder
		)
	) CheckSquare(iLeftTree, iRightTree, iTopTree, iBottomTree);
}


int main(void)
{
	freopen("cricket.in", "r", stdin);
	freopen("cricket.out", "w", stdout);

	scanf("%ld", &cTrees);
	fieldSize.Read();

	long iTree;
	for(iTree = 0; iTree < cTrees; ++iTree)
	{
		treesSortedXY[iTree].Read();
		treesSortedYX[iTree] = treesSortedXY[iTree];
	} 

	qsort(treesSortedXY, cTrees, sizeof(treesSortedXY[0]),
		(tpQSortCompareFunction)TreesXYCompare);
	qsort(treesSortedYX, cTrees, sizeof(treesSortedYX[0]),
		(tpQSortCompareFunction)TreesYXCompare);

	long iLeftTree, iRightTree, iTopTree, iBottomTree;

	for(iLeftTree = -1; iLeftTree < cTrees; ++iLeftTree)
		for(iRightTree = iLeftTree + 1; iRightTree <= cTrees; ++iRightTree)
			CheckXStripe(iLeftTree, iRightTree);

	for(iBottomTree = -1; iBottomTree < cTrees; ++iBottomTree)
		for(iTopTree = iBottomTree + 1; iTopTree <= cTrees; ++iTopTree)
			CheckYStripe(iBottomTree, iTopTree);

	printf("%ld %ld %ld", maxSquareBottomLeft.x, maxSquareBottomLeft.y, maxSquareSide);

	fclose(stdout);
	fclose(stdin);

	return 0;
}